#include "wizproptreepane.h"

#include <owl/radiobut.h>
#include <classlib/arrays.h>

// A class to hold info about child panes we need to add.
//
class TChildPaneInfo {
  public:
    TChildPaneInfo()
    : title(""), help("")
    {
      id = 0;
      resId = 0;
    }

    TChildPaneInfo( uint32 theId, TResId theResId, const char far *theTitle,
                    const char far *helpText )
    : title(theTitle), help(helpText)
    {
      id = theId;
      resId = theResId;
    }

    TChildPaneInfo&
    operator = (const TChildPaneInfo& other)
    {
      id = other.GetId();
      resId = other.GetResId();
      title = other.GetTitle();
      help = other.GetHelpText();
      return *this;
    }

    int
    operator == (const TChildPaneInfo& other)
    {
      return (id == other.GetId()) &&
             (resId == other.GetResId()) &&
             (title == other.GetTitle()) &&
             (help == other.GetHelpText());
    }

    ~TChildPaneInfo()
    {}

    uint32 GetId() const
    {
      return id;
    }

    TResId GetResId() const
    {
      return resId;
    }

    string GetTitle() const
    {
      return title;
    }

    string GetHelpText() const
    {
      return help;
    }

  private:
    uint32 id;
    TResId resId;
    string title;
    string help;
};


typedef TArrayAsVector<TChildPaneInfo> TChildInfoArray;
typedef TArrayAsVectorIterator<TChildPaneInfo> TChildInfoArrayIter;


class TRadioWizPane : public TWizPropTreePane {

  public:
    TRadioWizPane( TWizPropTreeDialog* parent,
                   uint32 uniqueId,
                   uint32 ifYes,
                   uint32 ifNo,
                   TChildInfoArray children,
                   const char far *helpText,
                   TResId resId,
                   TModule* module = 0);
    ~TRadioWizPane();

  protected:

    // When we ok KillActive (by returning false), we immediately
    // call SetState( wuDone ) to inform the proptree that we're done.
    //
    virtual bool KillActive();

    virtual void SetupWindow();

  private:

    TRadioButton *yesRadio;
    TRadioButton *noRadio;

    uint32 yesNext;
    uint32 noNext;

    bool panesAdded;

    TChildInfoArray children;
};
